@@ -34,7 +34,12 @@ class RedisClient():
 
         # Clear the database if fresh_start is set to true
         if fresh_start:
-            self.engine.flushdb()    
+            self.engine.flushdb()
+    
+
+    def close(self) -> None:
+        """ Closes the redis connection """
+        self.engine.close()
 
 
     def get_all_keys(self) -> list:
