@@ -1,5 +1,8 @@
+# Standard imports
+from sqlalchemy import create_engine
+
 # Third-party imports
-from sqlalchemy import SQLAlchemy
+from ._sqlalchemy import SQLAlchemy
 
 
 class TrinoClient(SQLAlchemy):
@@ -16,4 +19,13 @@ class TrinoClient(SQLAlchemy):
                 username (str): Username for authentication/privileges
                 password (str): Password for authentication
         """
-        super().__init__(engine = "trino", host = host, port = port, catalog = catalog, schema = schema, username = username, password = password)
\ No newline at end of file
+        super().__init__(engine = "trino", host = host, port = port, database = catalog, username = username, password = password)
+        self.schema = schema
+
+        self.engine = create_engine(self.connection_string)
+
+
+    @property
+    def connection_string(self) -> str:
+        """ Returns the connection string """
+        return f"{self.engine}://{self.username}:{self.password}@{self.host}:{self.port}/{self.database}/{self.schema}"
\ No newline at end of file
